@@ -20,9 +20,11 @@ class Browser(object):
 		#options.binary_location = "C:\\Program Files\\Chrome\\chrome64_55.0.2883.75\\chrome.exe"
 		#driver = webdriver.Chrome(chrome_options = options, executable_path=r'C:\path\to\chromedriver.exe')
 		if driver in ["chrome", "google chrome", "chromedriver"]:
-			self.driver = webdriver.Chrome(f'{SOURCE_PATH}/{VERSION}/classes/browser/drivers/{OS}/chromedriver')
+			#self.driver = webdriver.Chrome(f'{SOURCE_PATH}/{VERSION}/classes/browser/drivers/{OS}/chromedriver')
+			self.driver = webdriver.Chrome("/usr/local/bin/chromedriver")
 		elif driver in ["firefox", "geckodriver"]:
-			self.driver = webdriver.Firefox(executable_path=f'{SOURCE_PATH}/{VERSION}/classes/browser/drivers/{OS}/geckodriver')
+			#self.driver = webdriver.Firefox(executable_path=f'{SOURCE_PATH}/{VERSION}/classes/browser/drivers/{OS}/geckodriver')
+			self.driver = webdriver.Firefox(executable_path="/usr/local/bin/geckodriver")
 		else:
 			raise ValueError(f"Unkown driver: {driver}")
 
