@@ -6,6 +6,30 @@ from syst3m.v1.classes.config import *
 from syst3m.v1.classes import utils
 import platform 
 
+# kill pid.
+def kill(
+	# the process id.
+	pid=None, 
+	# sudo required.
+	sudo=False,
+	# loader.
+	loader=True,
+):
+	if loader:
+		log_level = 0
+		loader_ = syst3m.console.Loader(f"Killing process {pid}.")
+	else:
+		log_level = -1
+	if sudo: _sudo_ = "sudo "
+	else: _sudo_ = ""
+	output = syst3m.utils.__execute_script__(f"{_sudo_}kill {pid}")
+	if "terminated" in output:
+		if loader: loader_.stop()
+		return r3sponse.success_response(f"Successfully killed process {pid}.")
+	else:
+		if loader: loader_.stop(success=False)
+		return r3sponse.error_response(f"Failed to stop process {pid}, error: {output}", log_level=log_level)
+
 # defaults object class.
 class Defaults(object):
 	def __init__(self):
